from .base import ApiBase
import requests

class Members(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, idMember_or_username, actions=None, actions_entities=None, actions_display=None, actions_limit=None, action_fields=None, action_since=None, action_before=None, cards=None, card_fields=None, card_members=None, card_member_fields=None, card_attachments=None, card_attachment_fields=None, card_stickers=None, boards=None, board_fields=None, board_actions=None, board_actions_entities=None, board_actions_display=None, board_actions_format=None, board_actions_since=None, board_actions_limit=None, board_action_fields=None, board_lists=None, board_memberships=None, board_organization=None, board_organization_fields=None, boardsInvited=None, boardsInvited_fields=None, boardStars=None, savedSearches=None, organizations=None, organization_fields=None, organization_paid_account=None, organizationsInvited=None, organizationsInvited_fields=None, notifications=None, notifications_entities=None, notifications_display=None, notifications_limit=None, notification_fields=None, notification_memberCreator=None, notification_memberCreator_fields=None, notification_before=None, notification_since=None, tokens=None, paid_account=None, boardBackgrounds=None, customBoardBackgrounds=None, customStickers=None, customEmoji=None, fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}", params={"key": self._apikey, "token": self._token, "actions": actions, "actions_entities": actions_entities, "actions_display": actions_display, "actions_limit": actions_limit, "action_fields": action_fields, "action_since": action_since, "action_before": action_before, "cards": cards, "card_fields": card_fields, "card_members": card_members, "card_member_fields": card_member_fields, "card_attachments": card_attachments, "card_attachment_fields": card_attachment_fields, "card_stickers": card_stickers, "boards": boards, "board_fields": board_fields, "board_actions": board_actions, "board_actions_entities": board_actions_entities, "board_actions_display": board_actions_display, "board_actions_format": board_actions_format, "board_actions_since": board_actions_since, "board_actions_limit": board_actions_limit, "board_action_fields": board_action_fields, "board_lists": board_lists, "board_memberships": board_memberships, "board_organization": board_organization, "board_organization_fields": board_organization_fields, "boardsInvited": boardsInvited, "boardsInvited_fields": boardsInvited_fields, "boardStars": boardStars, "savedSearches": savedSearches, "organizations": organizations, "organization_fields": organization_fields, "organization_paid_account": organization_paid_account, "organizationsInvited": organizationsInvited, "organizationsInvited_fields": organizationsInvited_fields, "notifications": notifications, "notifications_entities": notifications_entities, "notifications_display": notifications_display, "notifications_limit": notifications_limit, "notification_fields": notification_fields, "notification_memberCreator": notification_memberCreator, "notification_memberCreator_fields": notification_memberCreator_fields, "notification_before": notification_before, "notification_since": notification_since, "tokens": tokens, "paid_account": paid_account, "boardBackgrounds": boardBackgrounds, "customBoardBackgrounds": customBoardBackgrounds, "customStickers": customStickers, "customEmoji": customEmoji, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_action(self, idMember_or_username, entities=None, display=None, filter=None, fields=None, limit=None, format=None, since=None, before=None, page=None, idModels=None, member=None, member_fields=None, memberCreator=None, memberCreator_fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/actions", params={"key": self._apikey, "token": self._token, "entities": entities, "display": display, "filter": filter, "fields": fields, "limit": limit, "format": format, "since": since, "before": before, "page": page, "idModels": idModels, "member": member, "member_fields": member_fields, "memberCreator": memberCreator, "memberCreator_fields": memberCreator_fields}, data=None)
        return self.raise_or_json(resp)

    def get_boardBackground(self, idMember_or_username, filter=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/boardBackgrounds", params={"key": self._apikey, "token": self._token, "filter": filter}, data=None)
        return self.raise_or_json(resp)

    def get_boardBackground_idBoardBackground(self, idBoardBackground, idMember_or_username, fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/boardBackgrounds/{idBoardBackground}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_boardStar(self, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/boardStars", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_boardStar_idBoardStar(self, idBoardStar, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/boardStars/{idBoardStar}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_board(self, idMember_or_username, filter=None, fields=None, actions=None, actions_entities=None, actions_limit=None, actions_format=None, actions_since=None, action_fields=None, memberships=None, organization=None, organization_fields=None, lists=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/boards", params={"key": self._apikey, "token": self._token, "filter": filter, "fields": fields, "actions": actions, "actions_entities": actions_entities, "actions_limit": actions_limit, "actions_format": actions_format, "actions_since": actions_since, "action_fields": action_fields, "memberships": memberships, "organization": organization, "organization_fields": organization_fields, "lists": lists}, data=None)
        return self.raise_or_json(resp)

    def get_board_filter(self, filter, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/boards/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_boardsInvited(self, idMember_or_username, fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/boardsInvited", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_boardsInvited_field(self, field, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/boardsInvited/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_card(self, idMember_or_username, actions=None, attachments=None, attachment_fields=None, stickers=None, members=None, member_fields=None, checkItemStates=None, checklists=None, limit=None, since=None, before=None, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/cards", params={"key": self._apikey, "token": self._token, "actions": actions, "attachments": attachments, "attachment_fields": attachment_fields, "stickers": stickers, "members": members, "member_fields": member_fields, "checkItemStates": checkItemStates, "checklists": checklists, "limit": limit, "since": since, "before": before, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_card_filter(self, filter, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/cards/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_customBoardBackground(self, idMember_or_username, filter=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/customBoardBackgrounds", params={"key": self._apikey, "token": self._token, "filter": filter}, data=None)
        return self.raise_or_json(resp)

    def get_customBoardBackground_idBoardBackground(self, idBoardBackground, idMember_or_username, fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/customBoardBackgrounds/{idBoardBackground}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_customEmoji(self, idMember_or_username, filter=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/customEmoji", params={"key": self._apikey, "token": self._token, "filter": filter}, data=None)
        return self.raise_or_json(resp)

    def get_customEmoji_idCustomEmoji(self, idCustomEmoji, idMember_or_username, fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/customEmoji/{idCustomEmoji}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_customSticker(self, idMember_or_username, filter=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/customStickers", params={"key": self._apikey, "token": self._token, "filter": filter}, data=None)
        return self.raise_or_json(resp)

    def get_customSticker_idCustomSticker(self, idCustomSticker, idMember_or_username, fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/customStickers/{idCustomSticker}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_delta(self, idMember_or_username, tags, ixLastUpdate):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/deltas", params={"key": self._apikey, "token": self._token, "tags": tags, "ixLastUpdate": ixLastUpdate}, data=None)
        return self.raise_or_json(resp)

    def get_notification(self, idMember_or_username, entities=None, display=None, filter=None, read_filter=None, fields=None, limit=None, page=None, before=None, since=None, memberCreator=None, memberCreator_fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/notifications", params={"key": self._apikey, "token": self._token, "entities": entities, "display": display, "filter": filter, "read_filter": read_filter, "fields": fields, "limit": limit, "page": page, "before": before, "since": since, "memberCreator": memberCreator, "memberCreator_fields": memberCreator_fields}, data=None)
        return self.raise_or_json(resp)

    def get_notification_filter(self, filter, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/notifications/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_organization(self, idMember_or_username, filter=None, fields=None, paid_account=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/organizations", params={"key": self._apikey, "token": self._token, "filter": filter, "fields": fields, "paid_account": paid_account}, data=None)
        return self.raise_or_json(resp)

    def get_organization_filter(self, filter, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/organizations/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_organizationsInvited(self, idMember_or_username, fields=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/organizationsInvited", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_organizationsInvited_field(self, field, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/organizationsInvited/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_savedSearche(self, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/savedSearches", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_savedSearche_idSavedSearch(self, idSavedSearch, idMember_or_username):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/savedSearches/{idSavedSearch}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_token(self, idMember_or_username, filter=None, webhooks=None):
        resp = requests.get(f"https://trello.com/1/members/{idMember_or_username}/tokens", params={"key": self._apikey, "token": self._token, "filter": filter, "webhooks": webhooks}, data=None)
        return self.raise_or_json(resp)

    def update(self, idMember_or_username, fullName=None, initials=None, username=None, bio=None, avatarSource=None, prefs_colorBlind=None, prefs_locale=None, prefs_minutesBetweenSummaries=None):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}", params={"key": self._apikey, "token": self._token}, data={"fullName": fullName, "initials": initials, "username": username, "bio": bio, "avatarSource": avatarSource, "prefs/colorBlind": prefs_colorBlind, "prefs/locale": prefs_locale, "prefs/minutesBetweenSummaries": prefs_minutesBetweenSummaries})
        return self.raise_or_json(resp)

    def update_avatarSource(self, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/avatarSource", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_bio(self, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/bio", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_boardBackground_idBoardBackground(self, idBoardBackground, idMember_or_username, tile=None, brightness=None):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/boardBackgrounds/{idBoardBackground}", params={"key": self._apikey, "token": self._token}, data={"tile": tile, "brightness": brightness})
        return self.raise_or_json(resp)

    def update_boardStar(self, idMember_or_username, idBoard=None, pos=None):
        resp = requests.put("https://trello.com/1/members/{}/boardStars/{}".format(idMember_or_username), params={"key": self._apikey, "token": self._token}, data={"idBoard": idBoard, "pos": pos})
        return self.raise_or_json(resp)

    def update_boardStar_idBoard_idBoardStar(self, idBoardStar, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/boardStars/{idBoardStar}/idBoard", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_boardStar_po_idBoardStar(self, idBoardStar, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/boardStars/{idBoardStar}/pos", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_customBoardBackground_idBoardBackground(self, idBoardBackground, idMember_or_username, tile=None, brightness=None):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/customBoardBackgrounds/{idBoardBackground}", params={"key": self._apikey, "token": self._token}, data={"tile": tile, "brightness": brightness})
        return self.raise_or_json(resp)

    def update_fullName(self, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/fullName", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_initial(self, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/initials", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_colorBlind(self, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/prefs/colorBlind", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_locale(self, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/prefs/locale", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_minutesBetweenSummarie(self, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/prefs/minutesBetweenSummaries", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_savedSearche(self, idMember_or_username, name=None, query=None, pos=None):
        resp = requests.put("https://trello.com/1/members/{}/savedSearches/{}".format(idMember_or_username), params={"key": self._apikey, "token": self._token}, data={"name": name, "query": query, "pos": pos})
        return self.raise_or_json(resp)

    def update_savedSearche_name_idSavedSearch(self, idSavedSearch, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/savedSearches/{idSavedSearch}/name", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_savedSearche_po_idSavedSearch(self, idSavedSearch, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/savedSearches/{idSavedSearch}/pos", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_savedSearche_query_idSavedSearch(self, idSavedSearch, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/savedSearches/{idSavedSearch}/query", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_username(self, idMember_or_username, value):
        resp = requests.put(f"https://trello.com/1/members/{idMember_or_username}/username", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new_avatar(self, idMember_or_username, file):
        resp = requests.post(f"https://trello.com/1/members/{idMember_or_username}/avatar", params={"key": self._apikey, "token": self._token}, data={"file": file})
        return self.raise_or_json(resp)

    def new_boardBackground(self, idMember_or_username, file):
        resp = requests.post(f"https://trello.com/1/members/{idMember_or_username}/boardBackgrounds", params={"key": self._apikey, "token": self._token}, data={"file": file})
        return self.raise_or_json(resp)

    def new_boardStar(self, idMember_or_username, idBoard, pos):
        resp = requests.post(f"https://trello.com/1/members/{idMember_or_username}/boardStars", params={"key": self._apikey, "token": self._token}, data={"idBoard": idBoard, "pos": pos})
        return self.raise_or_json(resp)

    def new_customBoardBackground(self, idMember_or_username, file):
        resp = requests.post(f"https://trello.com/1/members/{idMember_or_username}/customBoardBackgrounds", params={"key": self._apikey, "token": self._token}, data={"file": file})
        return self.raise_or_json(resp)

    def new_customEmoji(self, idMember_or_username, file, name):
        resp = requests.post(f"https://trello.com/1/members/{idMember_or_username}/customEmoji", params={"key": self._apikey, "token": self._token}, data={"file": file, "name": name})
        return self.raise_or_json(resp)

    def new_customSticker(self, idMember_or_username, file):
        resp = requests.post(f"https://trello.com/1/members/{idMember_or_username}/customStickers", params={"key": self._apikey, "token": self._token}, data={"file": file})
        return self.raise_or_json(resp)

    def new_oneTimeMessagesDismissed(self, idMember_or_username, value):
        resp = requests.post(f"https://trello.com/1/members/{idMember_or_username}/oneTimeMessagesDismissed", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new_savedSearche(self, idMember_or_username, name, query, pos):
        resp = requests.post(f"https://trello.com/1/members/{idMember_or_username}/savedSearches", params={"key": self._apikey, "token": self._token}, data={"name": name, "query": query, "pos": pos})
        return self.raise_or_json(resp)

    def delete_boardBackground_idBoardBackground(self, idBoardBackground, idMember_or_username):
        resp = requests.delete(f"https://trello.com/1/members/{idMember_or_username}/boardBackgrounds/{idBoardBackground}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_boardStar_idBoardStar(self, idBoardStar, idMember_or_username):
        resp = requests.delete(f"https://trello.com/1/members/{idMember_or_username}/boardStars/{idBoardStar}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_customBoardBackground_idBoardBackground(self, idBoardBackground, idMember_or_username):
        resp = requests.delete(f"https://trello.com/1/members/{idMember_or_username}/customBoardBackgrounds/{idBoardBackground}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_customSticker_idCustomSticker(self, idCustomSticker, idMember_or_username):
        resp = requests.delete(f"https://trello.com/1/members/{idMember_or_username}/customStickers/{idCustomSticker}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_savedSearche_idSavedSearch(self, idSavedSearch, idMember_or_username):
        resp = requests.delete(f"https://trello.com/1/members/{idMember_or_username}/savedSearches/{idSavedSearch}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Types(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, team_or_user_id):
        resp = requests.get(f"https://trello.com/1/types/{team_or_user_id}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Boards(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, board_id, actions=None, actions_entities=None, actions_display=None, actions_format=None, actions_since=None, actions_limit=None, action_fields=None, action_member=None, action_member_fields=None, action_memberCreator=None, action_memberCreator_fields=None, cards=None, card_fields=None, card_attachments=None, card_attachment_fields=None, card_checklists=None, card_pluginData=None, card_stickers=None, boardStars=None, labels=None, label_fields=None, labels_limit=None, lists=None, list_fields=None, memberships=None, memberships_member=None, memberships_member_fields=None, members=None, member_fields=None, membersInvited=None, membersInvited_fields=None, pluginData=None, checklists=None, checklist_fields=None, organization=None, organization_fields=None, organization_memberships=None, organization_pluginData=None, myPrefs=None, tags=None, fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}", params={"key": self._apikey, "token": self._token, "actions": actions, "actions_entities": actions_entities, "actions_display": actions_display, "actions_format": actions_format, "actions_since": actions_since, "actions_limit": actions_limit, "action_fields": action_fields, "action_member": action_member, "action_member_fields": action_member_fields, "action_memberCreator": action_memberCreator, "action_memberCreator_fields": action_memberCreator_fields, "cards": cards, "card_fields": card_fields, "card_attachments": card_attachments, "card_attachment_fields": card_attachment_fields, "card_checklists": card_checklists, "card_pluginData": card_pluginData, "card_stickers": card_stickers, "boardStars": boardStars, "labels": labels, "label_fields": label_fields, "labels_limit": labels_limit, "lists": lists, "list_fields": list_fields, "memberships": memberships, "memberships_member": memberships_member, "memberships_member_fields": memberships_member_fields, "members": members, "member_fields": member_fields, "membersInvited": membersInvited, "membersInvited_fields": membersInvited_fields, "pluginData": pluginData, "checklists": checklists, "checklist_fields": checklist_fields, "organization": organization, "organization_fields": organization_fields, "organization_memberships": organization_memberships, "organization_pluginData": organization_pluginData, "myPrefs": myPrefs, "tags": tags, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_action(self, board_id, entities=None, display=None, filter=None, fields=None, limit=None, format=None, since=None, before=None, page=None, idModels=None, member=None, member_fields=None, memberCreator=None, memberCreator_fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/actions", params={"key": self._apikey, "token": self._token, "entities": entities, "display": display, "filter": filter, "fields": fields, "limit": limit, "format": format, "since": since, "before": before, "page": page, "idModels": idModels, "member": member, "member_fields": member_fields, "memberCreator": memberCreator, "memberCreator_fields": memberCreator_fields}, data=None)
        return self.raise_or_json(resp)

    def get_boardStar(self, board_id, filter=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/boardStars", params={"key": self._apikey, "token": self._token, "filter": filter}, data=None)
        return self.raise_or_json(resp)

    def get_card(self, board_id, actions=None, attachments=None, attachment_fields=None, stickers=None, members=None, member_fields=None, checkItemStates=None, checklists=None, limit=None, since=None, before=None, filter=None, fields=None, customFieldItems=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/cards", params={"key": self._apikey, "token": self._token, "actions": actions, "attachments": attachments, "attachment_fields": attachment_fields, "stickers": stickers, "members": members, "member_fields": member_fields, "checkItemStates": checkItemStates, "checklists": checklists, "limit": limit, "since": since, "before": before, "filter": filter, "fields": fields, "customFieldItems": "true" if customFieldItems else None}, data=None)
        return self.raise_or_json(resp)

    def get_card_filter(self, filter, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/cards/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_card_idCard(self, idCard, board_id, attachments=None, attachment_fields=None, actions=None, actions_entities=None, actions_display=None, actions_limit=None, action_fields=None, action_memberCreator_fields=None, members=None, member_fields=None, checkItemStates=None, checkItemState_fields=None, labels=None, checklists=None, checklist_fields=None, fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/cards/{idCard}", params={"key": self._apikey, "token": self._token, "attachments": attachments, "attachment_fields": attachment_fields, "actions": actions, "actions_entities": actions_entities, "actions_display": actions_display, "actions_limit": actions_limit, "action_fields": action_fields, "action_memberCreator_fields": action_memberCreator_fields, "members": members, "member_fields": member_fields, "checkItemStates": checkItemStates, "checkItemState_fields": checkItemState_fields, "labels": labels, "checklists": checklists, "checklist_fields": checklist_fields, "fields": fields}, data=None)
        return self.raise_or_json(resp)
    
    def get_custom_fields(self, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/customFields", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_checklist(self, board_id, cards=None, card_fields=None, checkItems=None, checkItem_fields=None, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/checklists", params={"key": self._apikey, "token": self._token, "cards": cards, "card_fields": card_fields, "checkItems": checkItems, "checkItem_fields": checkItem_fields, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_delta(self, board_id, tags, ixLastUpdate):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/deltas", params={"key": self._apikey, "token": self._token, "tags": tags, "ixLastUpdate": ixLastUpdate}, data=None)
        return self.raise_or_json(resp)

    def get_label(self, board_id, fields=None, limit=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/labels", params={"key": self._apikey, "token": self._token, "fields": fields, "limit": limit}, data=None)
        return self.raise_or_json(resp)

    def get_label_idLabel(self, idLabel, board_id, fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/labels/{idLabel}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_list(self, board_id, cards=None, card_fields=None, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/lists", params={"key": self._apikey, "token": self._token, "cards": cards, "card_fields": card_fields, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_list_filter(self, filter, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/lists/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_member(self, board_id, filter=None, fields=None, activity=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/members", params={"key": self._apikey, "token": self._token, "filter": filter, "fields": fields, "activity": activity}, data=None)
        return self.raise_or_json(resp)

    def get_member_filter(self, filter, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/members/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_member_card_idMember(self, idMember, board_id, actions=None, attachments=None, attachment_fields=None, members=None, member_fields=None, checkItemStates=None, checklists=None, board=None, board_fields=None, list=None, list_fields=None, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/members/{idMember}/cards", params={"key": self._apikey, "token": self._token, "actions": actions, "attachments": attachments, "attachment_fields": attachment_fields, "members": members, "member_fields": member_fields, "checkItemStates": checkItemStates, "checklists": checklists, "board": board, "board_fields": board_fields, "list": list, "list_fields": list_fields, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_membersInvited(self, board_id, fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/membersInvited", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_membersInvited_field(self, field, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/membersInvited/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_membership(self, board_id, filter=None, member=None, member_fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/memberships", params={"key": self._apikey, "token": self._token, "filter": filter, "member": member, "member_fields": member_fields}, data=None)
        return self.raise_or_json(resp)

    def get_membership_idMembership(self, idMembership, board_id, member=None, member_fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/memberships/{idMembership}", params={"key": self._apikey, "token": self._token, "member": member, "member_fields": member_fields}, data=None)
        return self.raise_or_json(resp)

    def get_myPref(self, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/myPrefs", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_organization(self, board_id, fields=None):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/organization", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_organization_field(self, field, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/organization/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_pluginData(self, board_id):
        resp = requests.get(f"https://trello.com/1/boards/{board_id}/pluginData", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def update(self, board_id, name=None, desc=None, closed=None, subscribed=None, idOrganization=None, prefs_permissionLevel=None, prefs_selfJoin=None, prefs_cardCovers=None, prefs_invitations=None, prefs_voting=None, prefs_comments=None, prefs_background=None, prefs_cardAging=None, prefs_calendarFeedEnabled=None, labelNames_green=None, labelNames_yellow=None, labelNames_orange=None, labelNames_red=None, labelNames_purple=None, labelNames_blue=None):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}", params={"key": self._apikey, "token": self._token}, data={"name": name, "desc": desc, "closed": closed, "subscribed": subscribed, "idOrganization": idOrganization, "prefs/permissionLevel": prefs_permissionLevel, "prefs/selfJoin": prefs_selfJoin, "prefs/cardCovers": prefs_cardCovers, "prefs/invitations": prefs_invitations, "prefs/voting": prefs_voting, "prefs/comments": prefs_comments, "prefs/background": prefs_background, "prefs/cardAging": prefs_cardAging, "prefs/calendarFeedEnabled": prefs_calendarFeedEnabled, "labelNames/green": labelNames_green, "labelNames/yellow": labelNames_yellow, "labelNames/orange": labelNames_orange, "labelNames/red": labelNames_red, "labelNames/purple": labelNames_purple, "labelNames/blue": labelNames_blue})
        return self.raise_or_json(resp)

    def update_closed(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/closed", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_desc(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/desc", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_idOrganization(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/idOrganization", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_labelName_blue(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/labelNames/blue", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_labelName_green(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/labelNames/green", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_labelName_orange(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/labelNames/orange", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_labelName_purple(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/labelNames/purple", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_labelName_red(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/labelNames/red", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_labelName_yellow(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/labelNames/yellow", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_member(self, board_id, email, fullName=None, type=None):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/members", params={"key": self._apikey, "token": self._token}, data={"email": email, "fullName": fullName, "type": type})
        return self.raise_or_json(resp)

    def update_member_idMember(self, idMember, board_id, type):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/members/{idMember}", params={"key": self._apikey, "token": self._token}, data={"type": type})
        return self.raise_or_json(resp)

    def update_membership_idMembership(self, idMembership, board_id, type, member_fields=None):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/memberships/{idMembership}", params={"key": self._apikey, "token": self._token}, data={"type": type, "member_fields": member_fields})
        return self.raise_or_json(resp)

    def update_myPref_emailPosition(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/myPrefs/emailPosition", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_myPref_idEmailList(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/myPrefs/idEmailList", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_myPref_showListGuide(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/myPrefs/showListGuide", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_myPref_showSidebar(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/myPrefs/showSidebar", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_myPref_showSidebarActivity(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/myPrefs/showSidebarActivity", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_myPref_showSidebarBoardAction(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/myPrefs/showSidebarBoardActions", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_myPref_showSidebarMember(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/myPrefs/showSidebarMembers", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_name(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/name", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_background(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/background", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_calendarFeedEnabled(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/calendarFeedEnabled", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_cardAging(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/cardAging", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_cardCover(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/cardCovers", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_comment(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/comments", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_invitation(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/invitations", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_permissionLevel(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/permissionLevel", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_selfJoin(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/selfJoin", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_voting(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/prefs/voting", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_subscribed(self, board_id, value):
        resp = requests.put(f"https://trello.com/1/boards/{board_id}/subscribed", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new(self, name, defaultLabels=None, defaultLists=None, desc=None, idOrganization=None, idBoardSource=None, keepFromSource=None, powerUps=None, prefs_permissionLevel=None, prefs_voting=None, prefs_comments=None, prefs_invitations=None, prefs_selfJoin=None, prefs_cardCovers=None, prefs_background=None, prefs_cardAging=None):
        resp = requests.post("https://trello.com/1/boards", params={"key": self._apikey, "token": self._token}, data={"name": name, "defaultLabels": defaultLabels, "defaultLists": defaultLists, "desc": desc, "idOrganization": idOrganization, "idBoardSource": idBoardSource, "keepFromSource": keepFromSource, "powerUps": powerUps, "prefs_permissionLevel": prefs_permissionLevel, "prefs_voting": prefs_voting, "prefs_comments": prefs_comments, "prefs_invitations": prefs_invitations, "prefs_selfJoin": prefs_selfJoin, "prefs_cardCovers": prefs_cardCovers, "prefs_background": prefs_background, "prefs_cardAging": prefs_cardAging})
        return self.raise_or_json(resp)

    def new_calendarKey_generate(self, board_id):
        resp = requests.post(f"https://trello.com/1/boards/{board_id}/calendarKey/generate", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def new_checklist(self, board_id, name):
        resp = requests.post(f"https://trello.com/1/boards/{board_id}/checklists", params={"key": self._apikey, "token": self._token}, data={"name": name})
        return self.raise_or_json(resp)

    def new_emailKey_generate(self, board_id):
        resp = requests.post(f"https://trello.com/1/boards/{board_id}/emailKey/generate", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def new_label(self, board_id, name, color):
        resp = requests.post(f"https://trello.com/1/boards/{board_id}/labels", params={"key": self._apikey, "token": self._token}, data={"name": name, "color": color})
        return self.raise_or_json(resp)

    def new_list(self, board_id, name, pos=None):
        resp = requests.post(f"https://trello.com/1/boards/{board_id}/lists", params={"key": self._apikey, "token": self._token}, data={"name": name, "pos": pos})
        return self.raise_or_json(resp)

    def new_markAsViewed(self, board_id):
        resp = requests.post(f"https://trello.com/1/boards/{board_id}/markAsViewed", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def new_powerUp(self, board_id, value):
        resp = requests.post(f"https://trello.com/1/boards/{board_id}/powerUps", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def delete_member_idMember(self, idMember, board_id):
        resp = requests.delete(f"https://trello.com/1/boards/{board_id}/members/{idMember}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_powerUp_powerUp(self, powerUp, board_id):
        resp = requests.delete(f"https://trello.com/1/boards/{board_id}/powerUps/{powerUp}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Search(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, query, idBoards=None, idOrganizations=None, idCards=None, modelTypes=None, board_fields=None, boards_limit=None, card_fields=None, cards_limit=None, cards_page=None, card_board=None, card_list=None, card_members=None, card_stickers=None, card_attachments=None, organization_fields=None, organizations_limit=None, member_fields=None, members_limit=None, partial=None):
        resp = requests.get("https://trello.com/1/search", params={"key": self._apikey, "token": self._token, "query": query, "idBoards": idBoards, "idOrganizations": idOrganizations, "idCards": idCards, "modelTypes": modelTypes, "board_fields": board_fields, "boards_limit": boards_limit, "card_fields": card_fields, "cards_limit": cards_limit, "cards_page": cards_page, "card_board": card_board, "card_list": card_list, "card_members": card_members, "card_stickers": card_stickers, "card_attachments": card_attachments, "organization_fields": organization_fields, "organizations_limit": organizations_limit, "member_fields": member_fields, "members_limit": members_limit, "partial": partial}, data=None)
        return self.raise_or_json(resp)

    def get_member(self, query, limit=None, idBoard=None, idOrganization=None, onlyOrgMembers=None):
        resp = requests.get("https://trello.com/1/search/members", params={"key": self._apikey, "token": self._token, "query": query, "limit": limit, "idBoard": idBoard, "idOrganization": idOrganization, "onlyOrgMembers": onlyOrgMembers}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Notifications(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, idNotification, display=None, entities=None, fields=None, memberCreator=None, memberCreator_fields=None, board=None, board_fields=None, list=None, card=None, card_fields=None, organization=None, organization_fields=None, member=None, member_fields=None):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}", params={"key": self._apikey, "token": self._token, "display": display, "entities": entities, "fields": fields, "memberCreator": memberCreator, "memberCreator_fields": memberCreator_fields, "board": board, "board_fields": board_fields, "list": list, "card": card, "card_fields": card_fields, "organization": organization, "organization_fields": organization_fields, "member": member, "member_fields": member_fields}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_board(self, idNotification, fields=None):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/board", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_board_field(self, field, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/board/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_card(self, idNotification, fields=None):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/card", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_card_field(self, field, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/card/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_display(self, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/display", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_entitie(self, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/entities", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_list(self, idNotification, fields=None):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/list", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_list_field(self, field, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/list/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_member(self, idNotification, fields=None):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/member", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_member_field(self, field, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/member/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_memberCreator(self, idNotification, fields=None):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/memberCreator", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_memberCreator_field(self, field, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/memberCreator/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_organization(self, idNotification, fields=None):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/organization", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_organization_field(self, field, idNotification):
        resp = requests.get(f"https://trello.com/1/notifications/{idNotification}/organization/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def update(self, idNotification, unread=None):
        resp = requests.put(f"https://trello.com/1/notifications/{idNotification}", params={"key": self._apikey, "token": self._token}, data={"unread": unread})
        return self.raise_or_json(resp)

    def update_unread(self, idNotification, value):
        resp = requests.put(f"https://trello.com/1/notifications/{idNotification}/unread", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new_all_read(self, ):
        resp = requests.post("https://trello.com/1/notifications/all/read", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Batches(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, urls):
        resp = requests.get("https://trello.com/1/batch", params={"key": self._apikey, "token": self._token, "urls": urls}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Tokens(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, token, fields=None, webhooks=None):
        resp = requests.get(f"https://trello.com/1/tokens/{token}", params={"key": self._apikey, "token": self._token, "fields": fields, "webhooks": webhooks}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, token):
        resp = requests.get(f"https://trello.com/1/tokens/{token}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_member(self, token, fields=None):
        resp = requests.get(f"https://trello.com/1/tokens/{token}/member", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_member_field(self, field, token):
        resp = requests.get(f"https://trello.com/1/tokens/{token}/member/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_webhook(self, token):
        resp = requests.get(f"https://trello.com/1/tokens/{token}/webhooks", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_webhook_idWebhook(self, idWebhook, token):
        resp = requests.get(f"https://trello.com/1/tokens/{token}/webhooks/{idWebhook}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def update_webhook(self, token, callbackURL, idModel, description=None):
        resp = requests.put(f"https://trello.com/1/tokens/{token}/webhooks", params={"key": self._apikey, "token": self._token}, data={"callbackURL": callbackURL, "idModel": idModel, "description": description})
        return self.raise_or_json(resp)

    def new_webhook(self, token, callbackURL, idModel, description=None):
        resp = requests.post(f"https://trello.com/1/tokens/{token}/webhooks", params={"key": self._apikey, "token": self._token}, data={"callbackURL": callbackURL, "idModel": idModel, "description": description})
        return self.raise_or_json(resp)

    def delete(self, token):
        resp = requests.delete(f"https://trello.com/1/tokens/{token}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_webhook_idWebhook(self, idWebhook, token):
        resp = requests.delete(f"https://trello.com/1/tokens/{token}/webhooks/{idWebhook}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Organizations(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, idOrg_or_name, actions=None, actions_entities=None, actions_display=None, actions_limit=None, action_fields=None, memberships=None, memberships_member=None, memberships_member_fields=None, members=None, member_fields=None, member_activity=None, membersInvited=None, membersInvited_fields=None, pluginData=None, boards=None, board_fields=None, board_actions=None, board_actions_entities=None, board_actions_display=None, board_actions_format=None, board_actions_since=None, board_actions_limit=None, board_action_fields=None, board_lists=None, board_pluginData=None, paid_account=None, fields=None):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}", params={"key": self._apikey, "token": self._token, "actions": actions, "actions_entities": actions_entities, "actions_display": actions_display, "actions_limit": actions_limit, "action_fields": action_fields, "memberships": memberships, "memberships_member": memberships_member, "memberships_member_fields": memberships_member_fields, "members": members, "member_fields": member_fields, "member_activity": member_activity, "membersInvited": membersInvited, "membersInvited_fields": membersInvited_fields, "pluginData": pluginData, "boards": boards, "board_fields": board_fields, "board_actions": board_actions, "board_actions_entities": board_actions_entities, "board_actions_display": board_actions_display, "board_actions_format": board_actions_format, "board_actions_since": board_actions_since, "board_actions_limit": board_actions_limit, "board_action_fields": board_action_fields, "board_lists": board_lists, "board_pluginData": board_pluginData, "paid_account": paid_account, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, idOrg_or_name):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_action(self, idOrg_or_name, entities=None, display=None, filter=None, fields=None, limit=None, format=None, since=None, before=None, page=None, idModels=None, member=None, member_fields=None, memberCreator=None, memberCreator_fields=None):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/actions", params={"key": self._apikey, "token": self._token, "entities": entities, "display": display, "filter": filter, "fields": fields, "limit": limit, "format": format, "since": since, "before": before, "page": page, "idModels": idModels, "member": member, "member_fields": member_fields, "memberCreator": memberCreator, "memberCreator_fields": memberCreator_fields}, data=None)
        return self.raise_or_json(resp)

    def get_board(self, idOrg_or_name, filter=None, fields=None, actions=None, actions_entities=None, actions_limit=None, actions_format=None, actions_since=None, action_fields=None, memberships=None, organization=None, organization_fields=None, lists=None):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/boards", params={"key": self._apikey, "token": self._token, "filter": filter, "fields": fields, "actions": actions, "actions_entities": actions_entities, "actions_limit": actions_limit, "actions_format": actions_format, "actions_since": actions_since, "action_fields": action_fields, "memberships": memberships, "organization": organization, "organization_fields": organization_fields, "lists": lists}, data=None)
        return self.raise_or_json(resp)

    def get_board_filter(self, filter, idOrg_or_name):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/boards/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_delta(self, idOrg_or_name, tags, ixLastUpdate):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/deltas", params={"key": self._apikey, "token": self._token, "tags": tags, "ixLastUpdate": ixLastUpdate}, data=None)
        return self.raise_or_json(resp)

    def get_member(self, idOrg_or_name, filter=None, fields=None, activity=None):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/members", params={"key": self._apikey, "token": self._token, "filter": filter, "fields": fields, "activity": activity}, data=None)
        return self.raise_or_json(resp)

    def get_member_filter(self, filter, idOrg_or_name):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/members/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_member_card_idMember(self, idMember, idOrg_or_name, actions=None, attachments=None, attachment_fields=None, members=None, member_fields=None, checkItemStates=None, checklists=None, board=None, board_fields=None, list=None, list_fields=None, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/members/{idMember}/cards", params={"key": self._apikey, "token": self._token, "actions": actions, "attachments": attachments, "attachment_fields": attachment_fields, "members": members, "member_fields": member_fields, "checkItemStates": checkItemStates, "checklists": checklists, "board": board, "board_fields": board_fields, "list": list, "list_fields": list_fields, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_membersInvited(self, idOrg_or_name, fields=None):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/membersInvited", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_membersInvited_field(self, field, idOrg_or_name):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/membersInvited/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_membership(self, idOrg_or_name, filter=None, member=None):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/memberships", params={"key": self._apikey, "token": self._token, "filter": filter, "member": member}, data=None)
        return self.raise_or_json(resp)

    def get_membership_idMembership(self, idMembership, idOrg_or_name, member=None):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/memberships/{idMembership}", params={"key": self._apikey, "token": self._token, "member": member}, data=None)
        return self.raise_or_json(resp)

    def get_pluginData(self, idOrg_or_name):
        resp = requests.get(f"https://trello.com/1/organizations/{idOrg_or_name}/pluginData", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def update(self, idOrg_or_name, prefs_orgInviteRestrict=None, prefs_externalMembersDisabled=None, prefs_associatedDomain=None, prefs_googleAppsVersion=None, prefs_boardVisibilityRestrict_private=None, prefs_boardVisibilityRestrict_org=None, prefs_boardVisibilityRestrict_public=None, name=None, displayName=None, desc=None, website=None, prefs_permissionLevel=None):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}", params={"key": self._apikey, "token": self._token}, data={"prefs/orgInviteRestrict": prefs_orgInviteRestrict, "prefs/externalMembersDisabled": prefs_externalMembersDisabled, "prefs/associatedDomain": prefs_associatedDomain, "prefs/googleAppsVersion": prefs_googleAppsVersion, "prefs/boardVisibilityRestrict/private": prefs_boardVisibilityRestrict_private, "prefs/boardVisibilityRestrict/org": prefs_boardVisibilityRestrict_org, "prefs/boardVisibilityRestrict/public": prefs_boardVisibilityRestrict_public, "name": name, "displayName": displayName, "desc": desc, "website": website, "prefs/permissionLevel": prefs_permissionLevel})
        return self.raise_or_json(resp)

    def update_desc(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/desc", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_displayName(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/displayName", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_member(self, idOrg_or_name, email, fullName, type=None):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/members", params={"key": self._apikey, "token": self._token}, data={"email": email, "fullName": fullName, "type": type})
        return self.raise_or_json(resp)

    def update_member_idMember(self, idMember, idOrg_or_name, type):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/members/{idMember}", params={"key": self._apikey, "token": self._token}, data={"type": type})
        return self.raise_or_json(resp)

    def update_member_deactivated_idMember(self, idMember, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/members/{idMember}/deactivated", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_membership_idMembership(self, idMembership, idOrg_or_name, type, member_fields=None):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/memberships/{idMembership}", params={"key": self._apikey, "token": self._token}, data={"type": type, "member_fields": member_fields})
        return self.raise_or_json(resp)

    def update_name(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/name", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_associatedDomain(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/associatedDomain", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_boardVisibilityRestrict_org(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/boardVisibilityRestrict/org", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_boardVisibilityRestrict_private(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/boardVisibilityRestrict/private", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_boardVisibilityRestrict_public(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/boardVisibilityRestrict/public", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_externalMembersDisabled(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/externalMembersDisabled", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_googleAppsVersion(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/googleAppsVersion", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_orgInviteRestrict(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/orgInviteRestrict", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_pref_permissionLevel(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/permissionLevel", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_website(self, idOrg_or_name, value):
        resp = requests.put(f"https://trello.com/1/organizations/{idOrg_or_name}/website", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new(self, name=None, displayName=None, desc=None, website=None):
        resp = requests.post("https://trello.com/1/organizations", params={"key": self._apikey, "token": self._token}, data={"name": name, "displayName": displayName, "desc": desc, "website": website})
        return self.raise_or_json(resp)

    def new_logo(self, idOrg_or_name, file):
        resp = requests.post(f"https://trello.com/1/organizations/{idOrg_or_name}/logo", params={"key": self._apikey, "token": self._token}, data={"file": file})
        return self.raise_or_json(resp)

    def delete(self, idOrg_or_name):
        resp = requests.delete(f"https://trello.com/1/organizations/{idOrg_or_name}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_logo(self, idOrg_or_name):
        resp = requests.delete(f"https://trello.com/1/organizations/{idOrg_or_name}/logo", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_member_idMember(self, idMember, idOrg_or_name):
        resp = requests.delete(f"https://trello.com/1/organizations/{idOrg_or_name}/members/{idMember}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_member_all_idMember(self, idMember, idOrg_or_name):
        resp = requests.delete(f"https://trello.com/1/organizations/{idOrg_or_name}/members/{idMember}/all", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_pref_associatedDomain(self, idOrg_or_name):
        resp = requests.delete(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/associatedDomain", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_pref_orgInviteRestrict(self, idOrg_or_name, value):
        resp = requests.delete(f"https://trello.com/1/organizations/{idOrg_or_name}/prefs/orgInviteRestrict", params={"key": self._apikey, "token": self._token, "value": value}, data=None)
        return self.raise_or_json(resp)




from requests.utils import quote
from .actions import Actions
from .batches import Batches
from .boards import Boards
from .cards import Cards
from .checklists import Checklists
from .labels import Labels
from .lists import Lists
from .members import Members
from .notifications import Notifications
from .organizations import Organizations
from .search import Search
from .tokens import Tokens
from .types import Types
from .webhooks import Webhooks

class TrelloApi(object):
    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token
        self.actions = Actions(apikey, token)
        self.batches = Batches(apikey, token)
        self.boards = Boards(apikey, token)
        self.cards = Cards(apikey, token)
        self.checklists = Checklists(apikey, token)
        self.labels = Labels(apikey, token)
        self.lists = Lists(apikey, token)
        self.members = Members(apikey, token)
        self.notifications = Notifications(apikey, token)
        self.organizations = Organizations(apikey, token)
        self.search = Search(apikey, token)
        self.tokens = Tokens(apikey, token)
        self.types = Types(apikey, token)
        self.webhooks = Webhooks(apikey, token)

    def set_token(self, token):
        self._token = token
        self.actions._token = token
        self.batches._token = token
        self.boards._token = token
        self.cards._token = token
        self.checklists._token = token
        self.labels._token = token
        self.lists._token = token
        self.members._token = token
        self.notifications._token = token
        self.organizations._token = token
        self.search._token = token
        self.tokens._token = token
        self.types._token = token
        self.webhooks._token = token

    def get_token_url(self, app_name, expires='30days', write_access=True):
        return f"https://trello.com/1/authorize?key={self._apikey}&name={quote(app_name)}&expiration={expires}&response_type=token&scope={'read,write' if write_access else 'read'}"



from .base import ApiBase
import warnings
import requests

class Webhooks(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get_(self, idWebhook):
        warnings.warn('.get_() is deprecated. Please use .get()', DeprecationWarning)
        return self.get(idWebhook)

    def get(self, idWebhook):
        resp = requests.get(f"https://trello.com/1/webhooks/{idWebhook}/", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, idWebhook):
        resp = requests.get(f"https://trello.com/1/webhooks/{idWebhook}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def update(self, idWebhook, description=None, callbackURL=None, idModel=None, active=None):
        resp = requests.put(f"https://trello.com/1/webhooks/{idWebhook}", params={"key": self._apikey, "token": self._token}, data={"description": description, "callbackURL": callbackURL, "idModel": idModel, "active": active})
        return self.raise_or_json(resp)

    def update_(self, callbackURL, idModel, description=None):
        warnings.warn('.update_() is deprecated. Please use .update()', DeprecationWarning)
        return self.update(callbackURL, idModel, description)

    def update_active(self, idWebhook, value):
        resp = requests.put(f"https://trello.com/1/webhooks/{idWebhook}/active", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_callbackURL(self, idWebhook, value):
        resp = requests.put(f"https://trello.com/1/webhooks/{idWebhook}/callbackURL", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_description(self, idWebhook, value):
        resp = requests.put(f"https://trello.com/1/webhooks/{idWebhook}/description", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_idModel(self, idWebhook, value):
        resp = requests.put(f"https://trello.com/1/webhooks/{idWebhook}/idModel", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new(self, callbackURL, idModel, description=None):
        resp = requests.post("https://trello.com/1/webhooks", params={"key": self._apikey, "token": self._token}, data={"callbackURL": callbackURL, "idModel": idModel, "description": description})
        return self.raise_or_json(resp)

    def delete(self, idWebhook):
        resp = requests.delete(f"https://trello.com/1/webhooks/{idWebhook}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests


class Actions(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, idAction, display=None, entities=None, fields=None, member=None, member_fields=None, memberCreator=None, memberCreator_fields=None):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}", params={"key": self._apikey, "token": self._token, "display": display, "entities": entities, "fields": fields, "member": member, "member_fields": member_fields, "memberCreator": memberCreator, "memberCreator_fields": memberCreator_fields}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_board(self, idAction, fields=None):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/board", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_board_field(self, field, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/board/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_card(self, idAction, fields=None):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/card", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_card_field(self, field, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/card/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_display(self, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/display", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_entitie(self, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/entities", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_list(self, idAction, fields=None):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/list", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_list_field(self, field, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/list/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_member(self, idAction, fields=None):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/member", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_member_field(self, field, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/member/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_memberCreator(self, idAction, fields=None):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/memberCreator", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_memberCreator_field(self, field, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/memberCreator/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_organization(self, idAction, fields=None):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/organization", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_organization_field(self, field, idAction):
        resp = requests.get(f"https://trello.com/1/actions/{idAction}/organization/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def update(self, idAction, text=None):
        resp = requests.put(f"https://trello.com/1/actions/{idAction}", params={"key": self._apikey, "token": self._token}, data={"text": text})
        return self.raise_or_json(resp)

    def update_text(self, idAction, value):
        resp = requests.put(f"https://trello.com/1/actions/{idAction}/text", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def delete(self, idAction):
        resp = requests.delete(f"https://trello.com/1/actions/{idAction}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Labels(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, idLabel, fields=None):
        resp = requests.get(f"https://trello.com/1/labels/{idLabel}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_board(self, idLabel, fields=None):
        resp = requests.get(f"https://trello.com/1/labels/{idLabel}/board", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_board_field(self, field, idLabel):
        resp = requests.get(f"https://trello.com/1/labels/{idLabel}/board/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def update(self, idLabel, name=None, color=None):
        resp = requests.put(f"https://trello.com/1/labels/{idLabel}", params={"key": self._apikey, "token": self._token}, data={"name": name, "color": color})
        return self.raise_or_json(resp)

    def update_color(self, idLabel, value):
        resp = requests.put(f"https://trello.com/1/labels/{idLabel}/color", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_name(self, idLabel, value):
        resp = requests.put(f"https://trello.com/1/labels/{idLabel}/name", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new(self, name, color, idBoard):
        resp = requests.post("https://trello.com/1/labels", params={"key": self._apikey, "token": self._token}, data={"name": name, "color": color, "idBoard": idBoard})
        return self.raise_or_json(resp)

    def delete(self, idLabel):
        resp = requests.delete(f"https://trello.com/1/labels/{idLabel}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Lists(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, idList, cards=None, card_fields=None, board=None, board_fields=None, fields=None):
        resp = requests.get(f"https://trello.com/1/lists/{idList}", params={"key": self._apikey, "token": self._token, "cards": cards, "card_fields": card_fields, "board": board, "board_fields": board_fields, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, idList):
        resp = requests.get(f"https://trello.com/1/lists/{idList}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_action(self, idList, entities=None, display=None, filter=None, fields=None, limit=None, format=None, since=None, before=None, page=None, idModels=None, member=None, member_fields=None, memberCreator=None, memberCreator_fields=None):
        resp = requests.get(f"https://trello.com/1/lists/{idList}/actions", params={"key": self._apikey, "token": self._token, "entities": entities, "display": display, "filter": filter, "fields": fields, "limit": limit, "format": format, "since": since, "before": before, "page": page, "idModels": idModels, "member": member, "member_fields": member_fields, "memberCreator": memberCreator, "memberCreator_fields": memberCreator_fields}, data=None)
        return self.raise_or_json(resp)

    def get_board(self, idList, fields=None):
        resp = requests.get(f"https://trello.com/1/lists/{idList}/board", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_board_field(self, field, idList):
        resp = requests.get(f"https://trello.com/1/lists/{idList}/board/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_card(self, idList, actions=None, attachments=None, attachment_fields=None, stickers=None, members=None, member_fields=None, checkItemStates=None, checklists=None, limit=None, since=None, before=None, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/lists/{idList}/cards", params={"key": self._apikey, "token": self._token, "actions": actions, "attachments": attachments, "attachment_fields": attachment_fields, "stickers": stickers, "members": members, "member_fields": member_fields, "checkItemStates": checkItemStates, "checklists": checklists, "limit": limit, "since": since, "before": before, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_card_filter(self, filter, idList):
        resp = requests.get(f"https://trello.com/1/lists/{idList}/cards/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def update(self, idList, name=None, closed=None, idBoard=None, pos=None, subscribed=None):
        resp = requests.put(f"https://trello.com/1/lists/{idList}", params={"key": self._apikey, "token": self._token}, data={"name": name, "closed": closed, "idBoard": idBoard, "pos": pos, "subscribed": subscribed})
        return self.raise_or_json(resp)

    def update_closed(self, idList, value):
        resp = requests.put(f"https://trello.com/1/lists/{idList}/closed", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_idBoard(self, idList, value, pos=None):
        resp = requests.put(f"https://trello.com/1/lists/{idList}/idBoard", params={"key": self._apikey, "token": self._token}, data={"value": value, "pos": pos})
        return self.raise_or_json(resp)

    def update_name(self, idList, value):
        resp = requests.put(f"https://trello.com/1/lists/{idList}/name", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_po(self, idList, value):
        resp = requests.put(f"https://trello.com/1/lists/{idList}/pos", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_subscribed(self, idList, value):
        resp = requests.put(f"https://trello.com/1/lists/{idList}/subscribed", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new(self, name, idBoard, idListSource=None, pos=None):
        resp = requests.post("https://trello.com/1/lists", params={"key": self._apikey, "token": self._token}, data={"name": name, "idBoard": idBoard, "idListSource": idListSource, "pos": pos})
        return self.raise_or_json(resp)

    def new_archiveAllCard(self, idList):
        resp = requests.post(f"https://trello.com/1/lists/{idList}/archiveAllCards", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def new_card(self, idList, name, due, desc=None, labels=None, idMembers=None):
        resp = requests.post(f"https://trello.com/1/lists/{idList}/cards", params={"key": self._apikey, "token": self._token}, data={"name": name, "due": due, "desc": desc, "labels": labels, "idMembers": idMembers})
        return self.raise_or_json(resp)

    def new_moveAllCard_idList(self, idList, idList2, idBoard):
        resp = requests.post(f"https://trello.com/1/lists/{idList}/moveAllCards", params={"key": self._apikey, "token": self._token}, data={"idBoard": idBoard, "idList": idList2})
        return self.raise_or_json(resp)




import unittest
import webbrowser

from trello import TrelloApi

# API Key from dummy account
API_KEY = 'a66228a769040f4a2739ca6593d6baff'

class _Test(unittest.TestCase):
    @property
    def api(self):
        token = None
        try:
            with open('.token', 'r') as fd:
                token = fd.read().strip()
        except FileNotFoundError:
            token = self.token
        return TrelloApi(API_KEY, token)

    @property
    def token(self):
        print('Opening browser to get new token...')
        api = TrelloApi(API_KEY)
        webbrowser.open(api.get_token_url('Testing Python Package', '30days', False))
        token = input('Trello token:\n')
        with open('.token', 'w') as fd:
            fd.write(token)
        return token



import setuptools

from textwrap import dedent

setuptools.setup(
    name='trello',
    version='0.9.6',
    packages=['trello'],
    license=dedent("""
        Redistribution and use in source and binary forms, with or without modification,
        are permitted provided that the following conditions are met:

        Redistributions of source code must retain the above copyright notice, this list
        of conditions and the following disclaimer.  Redistributions in binary form must
        reproduce the above copyright notice, this list of conditions and the following
        disclaimer in the documentation and/or other materials provided with the
        distribution.

        THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
        ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
        WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
        DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
        ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
        (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
        LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
        ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
        (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
        SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    """),
    description='Python library for interacting with the Trello API',
    long_description=dedent("""
        Python Trello API Wrapper

        This Python API is simply a wrapper around the Trello API

        Getting Started:

        To use the Trello API, install the package either by downloading the source and running

            $ python setup.py install

        or by using pip

            $ pip install trello

        Documentation:

        You can find documentation for the Python API at:

            http://packages.python.org/trello/

        And documentation for the Trello API at:

            https://trello.com/docs/api/
    """),
    author='tghw,kulikjak,waghanza,lukegb',
    author_email='ty@tghw.com',
    url='https://github.com/tghw/trello-py',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ],
    install_requires = [
        "requests",
    ],
    python_requires='>=3.6',
)



from .base import ApiBase
import requests

class Checklists(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, idChecklist, cards=None, card_fields=None, checkItems=None, checkItem_fields=None, fields=None):
        resp = requests.get(f"https://trello.com/1/checklists/{idChecklist}", params={"key": self._apikey, "token": self._token, "cards": cards, "card_fields": card_fields, "checkItems": checkItems, "checkItem_fields": checkItem_fields, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, idChecklist):
        resp = requests.get(f"https://trello.com/1/checklists/{idChecklist}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_board(self, idChecklist, fields=None):
        resp = requests.get(f"https://trello.com/1/checklists/{idChecklist}/board", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_board_field(self, field, idChecklist):
        resp = requests.get(f"https://trello.com/1/checklists/{idChecklist}/board/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_card(self, idChecklist, actions=None, attachments=None, attachment_fields=None, stickers=None, members=None, member_fields=None, checkItemStates=None, checklists=None, limit=None, since=None, before=None, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/checklists/{idChecklist}/cards", params={"key": self._apikey, "token": self._token, "actions": actions, "attachments": attachments, "attachment_fields": attachment_fields, "stickers": stickers, "members": members, "member_fields": member_fields, "checkItemStates": checkItemStates, "checklists": checklists, "limit": limit, "since": since, "before": before, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_card_filter(self, filter, idChecklist):
        resp = requests.get(f"https://trello.com/1/checklists/{idChecklist}/cards/{filter}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_checkItem(self, idChecklist, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/checklists/{idChecklist}/checkItems", params={"key": self._apikey, "token": self._token, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_checkItem_idCheckItem(self, idCheckItem, idChecklist, fields=None):
        resp = requests.get(f"https://trello.com/1/checklists/{idChecklist}/checkItems/{idCheckItem}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def update(self, idChecklist, name=None, pos=None):
        resp = requests.put(f"https://trello.com/1/checklists/{idChecklist}", params={"key": self._apikey, "token": self._token}, data={"name": name, "pos": pos})
        return self.raise_or_json(resp)

    def update_name(self, idChecklist, value):
        resp = requests.put(f"https://trello.com/1/checklists/{idChecklist}/name", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_po(self, idChecklist, value):
        resp = requests.put(f"https://trello.com/1/checklists/{idChecklist}/pos", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new(self, idCard, name=None, pos=None, idChecklistSource=None):
        resp = requests.post("https://trello.com/1/checklists", params={"key": self._apikey, "token": self._token}, data={"idCard": idCard, "name": name, "pos": pos, "idChecklistSource": idChecklistSource})
        return self.raise_or_json(resp)

    def new_checkItem(self, idChecklist, name, pos=None, checked=None):
        resp = requests.post(f"https://trello.com/1/checklists/{idChecklist}/checkItems", params={"key": self._apikey, "token": self._token}, data={"name": name, "pos": pos, "checked": checked})
        return self.raise_or_json(resp)

    def delete(self, idChecklist):
        resp = requests.delete(f"https://trello.com/1/checklists/{idChecklist}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_checkItem_idCheckItem(self, idCheckItem, idChecklist):
        resp = requests.delete(f"https://trello.com/1/checklists/{idChecklist}/checkItems/{idCheckItem}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)




from .base import ApiBase
import requests

class Cards(ApiBase):
    __module__ = 'trello'

    def __init__(self, apikey, token=None):
        self._apikey = apikey
        self._token = token

    def get(self, card_id_or_shortlink, actions=None, actions_entities=None, actions_display=None, actions_limit=None, action_fields=None, action_memberCreator_fields=None, attachments=None, attachment_fields=None, members=None, member_fields=None, membersVoted=None, memberVoted_fields=None, checkItemStates=None, checkItemState_fields=None, checklists=None, checklist_fields=None, board=None, board_fields=None, list=None, list_fields=None, pluginData=None, stickers=None, sticker_fields=None, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}", params={"key": self._apikey, "token": self._token, "actions": actions, "actions_entities": actions_entities, "actions_display": actions_display, "actions_limit": actions_limit, "action_fields": action_fields, "action_memberCreator_fields": action_memberCreator_fields, "attachments": attachments, "attachment_fields": attachment_fields, "members": members, "member_fields": member_fields, "membersVoted": membersVoted, "memberVoted_fields": memberVoted_fields, "checkItemStates": checkItemStates, "checkItemState_fields": checkItemState_fields, "checklists": checklists, "checklist_fields": checklist_fields, "board": board, "board_fields": board_fields, "list": list, "list_fields": list_fields, "pluginData": pluginData, "stickers": stickers, "sticker_fields": sticker_fields, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_field(self, field, card_id_or_shortlink):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_action(self, card_id_or_shortlink, entities=None, display=None, filter=None, fields=None, limit=None, format=None, since=None, before=None, idModels=None, member=None, member_fields=None, memberCreator=None, memberCreator_fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/actions", params={"key": self._apikey, "token": self._token, "entities": entities, "display": display, "filter": filter, "fields": fields, "limit": limit, "format": format, "since": since, "before": before, "idModels": idModels, "member": member, "member_fields": member_fields, "memberCreator": memberCreator, "memberCreator_fields": memberCreator_fields}, data=None)
        return self.raise_or_json(resp)

    def get_attachment(self, card_id_or_shortlink, fields=None, filter=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/attachments", params={"key": self._apikey, "token": self._token, "fields": fields, "filter": filter}, data=None)
        return self.raise_or_json(resp)

    def get_attachment_idAttachment(self, idAttachment, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/attachments/{idAttachment}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_board(self, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/board", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_board_field(self, field, card_id_or_shortlink):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/board/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_checkItemState(self, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/checkItemStates", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_checklist(self, card_id_or_shortlink, cards=None, card_fields=None, checkItems=None, checkItem_fields=None, filter=None, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklists", params={"key": self._apikey, "token": self._token, "cards": cards, "card_fields": card_fields, "checkItems": checkItems, "checkItem_fields": checkItem_fields, "filter": filter, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_checkItem_idCheckItem(self, idCheckItem, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/checkItem/{idCheckItem}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_list(self, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/list", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_list_field(self, field, card_id_or_shortlink):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/list/{field}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_member(self, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/members", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_membersVoted(self, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/membersVoted", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_pluginData(self, card_id_or_shortlink):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/pluginData", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def get_sticker(self, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/stickers", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def get_sticker_idSticker(self, idSticker, card_id_or_shortlink, fields=None):
        resp = requests.get(f"https://trello.com/1/cards/{card_id_or_shortlink}/stickers/{idSticker}", params={"key": self._apikey, "token": self._token, "fields": fields}, data=None)
        return self.raise_or_json(resp)

    def update(self, card_id_or_shortlink, name=None, desc=None, closed=None, idMembers=None, idAttachmentCover=None, idList=None, idLabels=None, idBoard=None, pos=None, due=None, dueComplete=None, subscribed=None):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}", params={"key": self._apikey, "token": self._token}, data={"name": name, "desc": desc, "closed": closed, "idMembers": idMembers, "idAttachmentCover": idAttachmentCover, "idList": idList, "idLabels": idLabels, "idBoard": idBoard, "pos": pos, "due": due, "dueComplete": dueComplete, "subscribed": subscribed})
        return self.raise_or_json(resp)

    def update_action_comment_idAction(self, idAction, card_id_or_shortlink, text):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/actions/{idAction}/comments", params={"key": self._apikey, "token": self._token}, data={"text": text})
        return self.raise_or_json(resp)

    def update_checklist_checkItem_name_idChecklist_idCheckItem(self, idChecklist, idCheckItem, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklist/{idChecklist}/checkItem/{idCheckItem}/name", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_checklist_checkItem_po_idChecklist_idCheckItem(self, idChecklist, idCheckItem, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklist/{idChecklist}/checkItem/{idCheckItem}/pos", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_checklist_checkItem_state_idChecklist_idCheckItem(self, idChecklist, idCheckItem, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklist/{idChecklist}/checkItem/{idCheckItem}/state", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_checklist_checkItem_idChecklistCurrent_idCheckItem(self, idChecklistCurrent, idCheckItem, card_id_or_shortlink, name=None, state=None, idChecklist=None, pos=None):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklist/{idChecklistCurrent}/checkItem/{idCheckItem}", params={"key": self._apikey, "token": self._token}, data={"name": name, "state": state, "idChecklist": idChecklist, "pos": pos})
        return self.raise_or_json(resp)

    def update_checkItem_idCheckItem(self, idCheckItem, card_id_or_shortlink, name=None, state=None, idChecklist=None, pos=None):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/checkItem/{idCheckItem}", params={"key": self._apikey, "token": self._token}, data={"name": name, "state": state, "idChecklist": idChecklist, "pos": pos})
        return self.raise_or_json(resp)

    def update_closed(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/closed", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_desc(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/desc", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_due(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/due", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_dueComplete(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/dueComplete", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_idAttachmentCover(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/idAttachmentCover", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_idBoard(self, card_id_or_shortlink, value, idList=None):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/idBoard", params={"key": self._apikey, "token": self._token}, data={"value": value, "idList": idList})
        return self.raise_or_json(resp)

    def update_idList(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/idList", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_idMember(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/idMembers", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_name(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/name", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_po(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/pos", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def update_sticker_idSticker(self, idSticker, card_id_or_shortlink, top=None, left=None, zIndex=None, rotate=None):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/stickers/{idSticker}", params={"key": self._apikey, "token": self._token}, data={"top": top, "left": left, "zIndex": zIndex, "rotate": rotate})
        return self.raise_or_json(resp)

    def update_subscribed(self, card_id_or_shortlink, value):
        resp = requests.put(f"https://trello.com/1/cards/{card_id_or_shortlink}/subscribed", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new(self, name, idList, desc=None, pos=None, due=None, dueComplete=None, idMembers=None, idLabels=None, urlSource=None, fileSource=None, idCardSource=None, keepFromSource=None):
        resp = requests.post("https://trello.com/1/cards", params={"key": self._apikey, "token": self._token}, data={"name": name, "idList": idList, "desc": desc, "pos": pos, "due": due, "dueComplete": dueComplete, "idMembers": idMembers, "idLabels": idLabels, "urlSource": urlSource, "fileSource": fileSource, "idCardSource": idCardSource, "keepFromSource": keepFromSource})
        return self.raise_or_json(resp)

    def new_action_comment(self, card_id_or_shortlink, text):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/actions/comments", params={"key": self._apikey, "token": self._token}, data={"text": text})
        return self.raise_or_json(resp)

    def new_attachment(self, card_id_or_shortlink, file=None, url=None, name=None, mimeType=None):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/attachments", params={"key": self._apikey, "token": self._token}, data={"file": file, "url": url, "name": name, "mimeType": mimeType})
        return self.raise_or_json(resp)

    def new_checklist_checkItem_idChecklist(self, idChecklist, card_id_or_shortlink, name, pos=None):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklist/{idChecklist}/checkItem", params={"key": self._apikey, "token": self._token}, data={"name": name, "pos": pos})
        return self.raise_or_json(resp)

    def new_checklist_checkItem_convertToCard_idChecklist_idCheckItem(self, idChecklist, idCheckItem, card_id_or_shortlink):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklist/{idChecklist}/checkItem/{idCheckItem}/convertToCard", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def new_checklist(self, card_id_or_shortlink, value=None, name=None, idChecklistSource=None):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklists", params={"key": self._apikey, "token": self._token}, data={"value": value, "name": name, "idChecklistSource": idChecklistSource})
        return self.raise_or_json(resp)

    def new_idLabel(self, card_id_or_shortlink, value):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/idLabels", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new_idMember(self, card_id_or_shortlink, value):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/idMembers", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new_label(self, card_id_or_shortlink, color, name=None):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/labels", params={"key": self._apikey, "token": self._token}, data={"color": color, "name": name})
        return self.raise_or_json(resp)

    def new_markAssociatedNotificationsRead(self, card_id_or_shortlink):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/markAssociatedNotificationsRead", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def new_membersVoted(self, card_id_or_shortlink, value):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/membersVoted", params={"key": self._apikey, "token": self._token}, data={"value": value})
        return self.raise_or_json(resp)

    def new_sticker(self, card_id_or_shortlink, image, top, left, zIndex, rotate=None):
        resp = requests.post(f"https://trello.com/1/cards/{card_id_or_shortlink}/stickers", params={"key": self._apikey, "token": self._token}, data={"image": image, "top": top, "left": left, "zIndex": zIndex, "rotate": rotate})
        return self.raise_or_json(resp)

    def delete(self, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_action_comment_idAction(self, idAction, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/actions/{idAction}/comments", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_attachment_idAttachment(self, idAttachment, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/attachments/{idAttachment}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_checklist_checkItem_idChecklist_idCheckItem(self, idChecklist, idCheckItem, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklist/{idChecklist}/checkItem/{idCheckItem}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_checkItem_idCheckItem(self, idCheckItem, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/checkItem/{idCheckItem}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_checklist_idChecklist(self, idChecklist, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/checklists/{idChecklist}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_idLabel_idLabel(self, idLabel, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/idLabels/{idLabel}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_idMember_idMember(self, idMember, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/idMembers/{idMember}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_membersVoted_idMember(self, idMember, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/membersVoted/{idMember}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

    def delete_sticker_idSticker(self, idSticker, card_id_or_shortlink):
        resp = requests.delete(f"https://trello.com/1/cards/{card_id_or_shortlink}/stickers/{idSticker}", params={"key": self._apikey, "token": self._token}, data=None)
        return self.raise_or_json(resp)

